CompositionFunctionApproximator
===============================

.. container:: subclasses

    *Subclasses*

    .. toctree::
       :maxdepth: 1

       RegressionCFA

    |

.. container:: related

    *Related*

    .. toctree::
       :maxdepth: 1

       OptimizationControlMechanism

.. automodule:: psyneulink.core.compositions.compositionfunctionapproximator
   :members:
   :private-members:
